@@ -1,5 +1,3 @@
-# -*- coding: utf8 -*-
-
 import sys
 import unittest
 
@@ -38,7 +36,7 @@ class BaseModuleTest(unittest.TestCase):
         """Ensure the SDL version is valid"""
         self.assertEqual(len(pygame.get_sdl_version()), 3)
 
-    class ExporterBase(object):
+    class ExporterBase:
         def __init__(self, shape, typechar, itemsize):
             import ctypes
 
@@ -158,7 +156,7 @@ class BaseModuleTest(unittest.TestCase):
 
         class Exporter(self.ExporterBase):
             def __init__(self, shape, typechar, itemsize):
-                super(Exporter, self).__init__(shape, typechar, itemsize)
+                super().__init__(shape, typechar, itemsize)
                 self.view = BufferProxy(self.__dict__)
 
             def get__array_struct__(self):
@@ -622,14 +620,6 @@ class BaseModuleTest(unittest.TestCase):
 
         self.assertFalse(pygame.get_init())
 
-    def todo_test_segfault(self):
-
-        # __doc__ (as of 2008-08-02) for pygame.base.segfault:
-
-        # crash
-
-        self.fail()
-
 
 if __name__ == "__main__":
     unittest.main()
